using System;
using System.Linq;
using System.Runtime.InteropServices;
using System.Windows;
using System.Collections;
using System.Collections.Generic;

public static class Win32
{
    [Flags]
    public enum WSC_SECURITY_PROVIDER : int
    {
        WSC_SECURITY_PROVIDER_FIREWALL = 1,
        WSC_SECURITY_PROVIDER_AUTOUPDATE_SETTINGS = 2,
        WSC_SECURITY_PROVIDER_ANTIVIRUS = 4,
        WSC_SECURITY_PROVIDER_ANTISPYWARE = 8,
        WSC_SECURITY_PROVIDER_INTERNET_SETTINGS = 16,
        WSC_SECURITY_PROVIDER_USER_ACCOUNT_CONTROL = 32,
        WSC_SECURITY_PROVIDER_SERVICE = 64,
        WSC_SECURITY_PROVIDER_NONE = 0,
        WSC_SECURITY_PROVIDER_ALL = WSC_SECURITY_PROVIDER_FIREWALL | WSC_SECURITY_PROVIDER_AUTOUPDATE_SETTINGS | WSC_SECURITY_PROVIDER_ANTIVIRUS |
        WSC_SECURITY_PROVIDER_ANTISPYWARE | WSC_SECURITY_PROVIDER_INTERNET_SETTINGS | WSC_SECURITY_PROVIDER_USER_ACCOUNT_CONTROL |
        WSC_SECURITY_PROVIDER_SERVICE | WSC_SECURITY_PROVIDER_NONE
    }

    [Flags]
    public enum WSC_SECURITY_PROVIDER_HEALTH : int
    {
        WSC_SECURITY_PROVIDER_HEALTH_GOOD, // Green pillar in English locales
        WSC_SECURITY_PROVIDER_HEALTH_NOTMONITORED, // Yellow pillar in English locales
        WSC_SECURITY_PROVIDER_HEALTH_POOR,  // Red pillar in English locales
        WSC_SECURITY_PROVIDER_HEALTH_SNOOZE, // Yellow pillar in English locales
        WSC_SECURITY_PROVIDER_HEALTH_UNKNOWN
    }

    [DllImport("wscapi.dll")]
    public static extern int WscGetSecurityProviderHealth(int inValue, ref int outValue);

    [UnmanagedFunctionPointer(CallingConvention.StdCall)]
    public delegate void WscChangedNotification(IntPtr param);

    public static WSC_SECURITY_PROVIDER_HEALTH GetSecurityProviderHealth(WSC_SECURITY_PROVIDER inputValue)
    {
        int inValue = (int)inputValue;
        int outValue = -1;

        int result = Win32.WscGetSecurityProviderHealth(inValue, ref outValue);

        foreach (WSC_SECURITY_PROVIDER_HEALTH wsph in Enum.GetValues(typeof(WSC_SECURITY_PROVIDER_HEALTH)))
            if ((int)wsph == outValue) return wsph;

        return WSC_SECURITY_PROVIDER_HEALTH.WSC_SECURITY_PROVIDER_HEALTH_UNKNOWN;
    }
}
namespace FireWallAntivirusUpdates
{
    class Program
    {
        static int Main(string[] args)
        {
            int overall_status = 0; //OK
            bool flag = false;
            Array a = Enum.GetValues(typeof(Win32.WSC_SECURITY_PROVIDER));
            foreach (Win32.WSC_SECURITY_PROVIDER sp in a)
            {
                if (sp == Win32.WSC_SECURITY_PROVIDER.WSC_SECURITY_PROVIDER_ANTIVIRUS || sp == Win32.WSC_SECURITY_PROVIDER.WSC_SECURITY_PROVIDER_FIREWALL || sp == Win32.WSC_SECURITY_PROVIDER.WSC_SECURITY_PROVIDER_AUTOUPDATE_SETTINGS)
                {
                    Win32.WSC_SECURITY_PROVIDER_HEALTH spStatus = Win32.GetSecurityProviderHealth(sp);
                    Console.Write("{0} - {1} ; ", sp.ToString().Replace("WSC_SECURITY_PROVIDER_", ""), spStatus.ToString().Replace("WSC_SECURITY_PROVIDER_HEALTH_", ""));
                    if ((spStatus.ToString().Contains("NOTMONITORED") || spStatus.ToString().Contains("SNOOZE")) && flag == false)
                    {
                        overall_status = 1; // Warning
                        flag = true;
                    }
                    else if (spStatus.ToString().Contains("POOR") && flag == false)
                    {
                        overall_status = 2; // Critical
                        flag = true;
                    }
                    else if (spStatus.ToString().Contains("UNKNOWN") && flag == false)
                    {
                        overall_status = 3; // Unknown
                        flag = true;
                    }
                }
            }
            Console.Write("\n");
            return overall_status;
        }
    }
}